@@ -442,62 +442,84 @@ class VectorSympy(Vector):  # noqa: PLW1641
 
     lib = _lib()
 
+    # The type ignore comments below cannot be removed because `VectorSympy`
+    # classes do not actually inherit from `numpy.ndarray`, but they
+    # implement numpy ufuncs for a uniform user-interface (such that users
+    # can use numpy functions on vectors regardless of backend). Additionally,
+    # SymPy expressions also implement numpy ufuncs, so this also aligns with
+    # that behavior. We can refactor out each `if` block in `__array_ufunc__`
+    # into separate functions to avoid the type ignore comments, but that
+    # would make the code less readable.
     def __eq__(self, other: typing.Any) -> typing.Any:
-        return numpy.equal(self, other)
+        return numpy.equal(self, other)  # type: ignore[call-overload]
 
     def __ne__(self, other: typing.Any) -> typing.Any:
-        return numpy.not_equal(self, other)
+        return numpy.not_equal(self, other)  # type: ignore[call-overload]
 
     def __abs__(self) -> float:
         return numpy.absolute(self)
 
     def __add__(self, other: VectorProtocol) -> VectorProtocol:
-        return numpy.add(self, other)
+        return numpy.add(self, other)  # type: ignore[call-overload]
 
     def __radd__(self, other: VectorProtocol) -> VectorProtocol:
-        return numpy.add(other, self)
+        return numpy.add(other, self)  # type: ignore[call-overload]
 
     def __iadd__(self: SameVectorType, other: VectorProtocol) -> SameVectorType:
-        return _replace_data(self, numpy.add(self, other))
+        return _replace_data(
+            self,
+            numpy.add(self, other),  # type: ignore[call-overload]
+        )
 
     def __sub__(self, other: VectorProtocol) -> VectorProtocol:
-        return numpy.subtract(self, other)
+        return numpy.subtract(self, other)  # type: ignore[call-overload]
 
     def __rsub__(self, other: VectorProtocol) -> VectorProtocol:
-        return numpy.subtract(other, self)
+        return numpy.subtract(other, self)  # type: ignore[call-overload]
 
     def __isub__(self: SameVectorType, other: VectorProtocol) -> SameVectorType:
-        return _replace_data(self, numpy.subtract(self, other))
+        return _replace_data(
+            self,
+            numpy.subtract(self, other),  # type: ignore[call-overload]
+        )
 
     def __mul__(self, other: float) -> VectorProtocol:
-        return numpy.multiply(self, other)
+        return numpy.multiply(self, other)  # type: ignore[call-overload]
 
     def __rmul__(self, other: float) -> VectorProtocol:
-        return numpy.multiply(other, self)
+        return numpy.multiply(other, self)  # type: ignore[call-overload]
 
     def __imul__(self: SameVectorType, other: float) -> SameVectorType:
-        return _replace_data(self, numpy.multiply(self, other))
+        return _replace_data(
+            self,
+            numpy.multiply(self, other),  # type: ignore[call-overload]
+        )
 
     def __neg__(self: SameVectorType) -> SameVectorType:
-        return numpy.negative(self)
+        return numpy.negative(self)  # type: ignore[call-overload]
 
     def __pos__(self: SameVectorType) -> SameVectorType:
-        return numpy.positive(self)
+        return numpy.positive(self)  # type: ignore[call-overload]
 
     def __truediv__(self, other: float) -> VectorProtocol:
-        return numpy.true_divide(self, other)
+        return numpy.true_divide(self, other)  # type: ignore[call-overload]
 
     def __rtruediv__(self, other: float) -> VectorProtocol:
-        return numpy.true_divide(other, self)
+        return numpy.true_divide(other, self)  # type: ignore[call-overload]
 
     def __itruediv__(self: SameVectorType, other: float) -> VectorProtocol:
-        return _replace_data(self, numpy.true_divide(self, other))
+        return _replace_data(
+            self,
+            numpy.true_divide(self, other),  # type: ignore[call-overload]
+        )
 
     def __pow__(self, other: float) -> float:
-        return numpy.power(self, other)
+        return (
+            numpy.square(self) if other == 2 else numpy.power(self, other)  # type: ignore[call-overload]
+        )
 
     def __matmul__(self, other: VectorProtocol) -> float:
-        return numpy.matmul(self, other)
+        return numpy.matmul(self, other)  # type: ignore[call-overload]
 
     def __array_ufunc__(
         self,
